These functions check the dbfiles and machines tables to see if the file
exists, and return the container_id (dbfile.id) or full filename
with path (dbfile.file) to the first one found.
If none is found, both will return NA.
Functions
dbfile.file(): Return full path to file from the dbfiles tabledbfile.id(): Return id to container type given a filename
Examples
if (FALSE) { # \dontrun{
type <- "Input"
id <- 7
dbcon <- db.open(list(host = "postgres", user = "bety", password = "carya"))
dbfile.file(type, id, dbcon)
} # }
if (FALSE) { # \dontrun{
type <- "Model"
file <- "/usr/local/bin/sipnet"
dbcon <- db.open(list(host = "postgres", user = "bety", password = "carya"))
dbfile.id(type, file, dbcon)
} # }