This function will move dbfiles - clim or nc - from one location
to another on the same machine and update BETY
Usage
dbfile.move(old.dir, new.dir, file.type, siteid = NULL, register = FALSE)
Arguments
- old.dir
directory with files to be moved
- new.dir
directory where files should be moved
- file.type
what type of files are being moved
- siteid
needed to register files that arent already in BETY
- register
if file isn't already in BETY, should it be registered?
Value
print statement of how many files were moved, registered, or have symbolic links
Examples
if (FALSE) { # \dontrun{
dbfile.move(
old.dir = "/fs/data3/kzarada/pecan.data/dbfiles/NOAA_GEFS_site_0-676",
new.dir = "/projectnb/dietzelab/pecan.data/dbfiles/NOAA_GEFS_site_0-676",
file.type= "clim",
siteid = 676,
register = TRUE
)
} # }